Skip to contents

Return a grid grob that you can place in another graphic, a table cell, or an rmarkdown inline chunk.

Usage

sparkline_grob(values, ...)

Arguments

values

Numeric vector of values, in order.

...

Passed to sparkline().

Value

A grid grob.

Examples

set.seed(1)
g <- sparkline_grob(cumsum(rnorm(50)))
grid::grid.newpage()
grid::grid.draw(g)